@@ -3,7 +3,6 @@ from .headerfooter import IncludeHeaderFooter
 from .lockcells import LockCells
 from .clearsolutions import ClearSolutions
 from .saveautogrades import SaveAutoGrades
-from .displayautogrades import DisplayAutoGrades
 from .computechecksums import ComputeChecksums
 from .savecells import SaveCells
 from .overwritecells import OverwriteCells
@@ -14,6 +13,9 @@ from .clearoutput import ClearOutput
 from .limitoutput import LimitOutput
 from .deduplicateids import DeduplicateIds
 from .latesubmissions import AssignLatePenalties
+from .clearhiddentests import ClearHiddenTests
+from .clearmarkingscheme import ClearMarkScheme
+from .overwritekernelspec import OverwriteKernelspec
 
 __all__ = [
     "AssignLatePenalties",
@@ -21,7 +23,6 @@ __all__ = [
     "LockCells",
     "ClearSolutions",
     "SaveAutoGrades",
-    "DisplayAutoGrades",
     "ComputeChecksums",
     "SaveCells",
     "OverwriteCells",
@@ -30,5 +31,8 @@ __all__ = [
     "GetGrades",
     "ClearOutput",
     "LimitOutput",
-    "DeduplicateIds"
+    "DeduplicateIds",
+    "ClearHiddenTests",
+    "ClearMarkScheme",
+    "OverwriteKernelspec",
 ]
