@@ -1,15 +1,19 @@
-from nbformat import read as read_nb
+# -*- coding: utf-8 -*-
+
+import io
+
 from nbformat import current_nbformat
 from traitlets import Unicode
 
 from . import NbGraderPreprocessor
+from ..nbgraderformat import read as read_nb
 
 
 class IncludeHeaderFooter(NbGraderPreprocessor):
     """A preprocessor for adding header and/or footer cells to a notebook."""
 
-    header = Unicode("", config=True, help="Path to header notebook")
-    footer = Unicode("", config=True, help="Path to footer notebook")
+    header = Unicode("", help="Path to header notebook, relative to the root of the course directory").tag(config=True)
+    footer = Unicode("", help="Path to footer notebook, relative to the root of the course directory").tag(config=True)
 
     def preprocess(self, nb, resources):
         """Concatenates the cells from the header and footer notebooks to the
@@ -20,7 +24,7 @@ class IncludeHeaderFooter(NbGraderPreprocessor):
 
         # header
         if self.header:
-            with open(self.header, 'r') as fh:
+            with io.open(self.header, encoding='utf-8') as fh:
                 header_nb = read_nb(fh, as_version=current_nbformat)
             new_cells.extend(header_nb.cells)
 
@@ -29,7 +33,7 @@ class IncludeHeaderFooter(NbGraderPreprocessor):
 
         # footer
         if self.footer:
-            with open(self.footer, 'r') as fh:
+            with io.open(self.footer, encoding='utf-8') as fh:
                 footer_nb = read_nb(fh, as_version=current_nbformat)
             new_cells.extend(footer_nb.cells)
 
